@@ -29,7 +29,7 @@ class DingDingPlugin(NotificationPlugin):
     title = 'WbDingDing'
     conf_key = slug
     conf_title = title
-    isAtALL = false
+    isAtALL = False
     project_conf_form = DingDingOptionsForm
 
     def is_configured(self, project):
